@@ -12,11 +12,17 @@ import collections
 import re
 import urllib
 import urllib2
+import getpass
 
 import distutils2.version
 from distutils2.index.simple import Crawler, DEFAULT_SIMPLE_INDEX_URL
 
 
+def get_temp_dir():
+    user = getpass.getuser()
+    return tempfile.mkdtemp(prefix='pypi2rpm-%s-' % user)
+
+
 def _is_d2(location=os.curdir):
     """Returns True if the project is a Distutils2 Project"""
     setup_cfg = os.path.join(location, 'setup.cfg')
@@ -69,7 +75,7 @@ def get_release(project_name, version=None,
         if os.path.exists(target_file):
             return target_file
 
-    temp_path = tempfile.mkdtemp()
+    temp_path = get_temp_dir()
     try:
         path = release.download(temp_path)
         if download_cache is not None:
@@ -98,17 +104,24 @@ def _d1_sdist2rpm(dist_dir):
         name = '%s-%s' % (_PYTHON, name[len('python-'):])
 
     # run the bdist_rpm2 command
-    cmd = ('--command-packages=pypi2rpm.command bdist_rpm2 '
-           '--binary-only')
-    if dist_dir is not None:
-        cmd += ' --dist-dir=%s' % dist_dir
-    else:
-        cmd += ' --dist-dir=%s' % os.getcwd()
+    tmppath = get_temp_dir()
+    try:
+        cmd = ('--command-packages=pypi2rpm.command bdist_rpm2 '
+            '--binary-only '
+            '--tmppath %s' % tmppath)
+
+        if dist_dir is not None:
+            cmd += ' --dist-dir=%s' % dist_dir
+        else:
+            cmd += ' --dist-dir=%s' % os.getcwd()
+
+        call = '%s setup.py %s --name=%s --python=%s' % \
+                (sys.executable, cmd, name, os.path.basename(sys.executable))
+        print(call)
+        res = subprocess.call(call, shell=True)
+    finally:
+        shutil.rmtree(tmppath)
 
-    call = '%s setup.py %s --name=%s --python=%s' % \
-            (sys.executable, cmd, name, os.path.basename(sys.executable))
-    print(call)
-    res = subprocess.call(call, shell=True)
     if res != 0:
         print('Could not create RPM')
         sys.exit(1)
@@ -318,7 +331,7 @@ def sdist2rpm(sdist, dist_dir=None, version=None):
         dist_dir = old_dir
 
     if os.path.isfile(sdist):
-        tempdir = tempfile.mkdtemp()
+        tempdir = get_temp_dir()
         os.chdir(tempdir)
         unpack_archive(sdist, extract_dir=tempdir)
         sdist = os.listdir(os.curdir)[0]
